==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NXShell/BadArgumentFormat.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NXShell::BadArgumentFormat::BEGIN{package 
Exception::NXShell::BadArgumentFormat;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NXShell::BadArgumentFormat::BEGIN{package 
Exception::NXShell::BadArgumentFormat;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NXShell::BadArgumentFormat::notify{package 
Exception::NXShell::BadArgumentFormat;no warnings;(my $self=shift (@_));(my $text
=$self->text);NXMsg::register_response ((""),
"\x65\x47\x55\x49\x42\x61\x64\x41\x72\x67\x75\x6d\x65\x6e\x74\x46\x6f\x72\x6d\x61\x74"
,(0x099c+ 2568-0x114f));NXMsg::send_response (
"\x65\x47\x55\x49\x42\x61\x64\x41\x72\x67\x75\x6d\x65\x6e\x74\x46\x6f\x72\x6d\x61\x74"
,"\x67\x65\x6e\x65\x72\x61\x6c",$text);}package 
Exception::NXShell::BadArgumentFormat;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NXShell/BadArgumentFormat.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NXShell::BadArgumentFormat::BEGIN{package 
Exception::NXShell::BadArgumentFormat;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NXShell::BadArgumentFormat::BEGIN{package 
Exception::NXShell::BadArgumentFormat;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NXShell::BadArgumentFormat::notify{package 
Exception::NXShell::BadArgumentFormat;no warnings;(my $self=shift (@_));(my $text
=$self->text);NXMsg::register_response ((""),
"\x65\x47\x55\x49\x42\x61\x64\x41\x72\x67\x75\x6d\x65\x6e\x74\x46\x6f\x72\x6d\x61\x74"
,(0x0639+ 1800-0x0aec));NXMsg::send_response (
"\x65\x47\x55\x49\x42\x61\x64\x41\x72\x67\x75\x6d\x65\x6e\x74\x46\x6f\x72\x6d\x61\x74"
,"\x67\x65\x6e\x65\x72\x61\x6c",$text);}package 
Exception::NXShell::BadArgumentFormat;no warnings;"\x3f\x3f\x3f";
